@@ -86,7 +86,7 @@ def attachSettings(settingsDict, enablePaypal=False):
 
     authenticationBackends = tuple(authenticationBackends)
     
-    extendAuthenticationBackend(settingsDict, authenticationBackends)
+    update(settingsDict, authenticationBackends)
     #=========================================================================
     
     #=========================================================================
@@ -126,12 +126,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     # Oscar default currency
     OSCAR_DEFAULT_CURRENCY = 'USD'
-    #=========================================================================
-    ADDING_AUTHENTICATION_BACKENDS = (
-        'django.contrib.auth.backends.ModelBackend',
-        'oscar.apps.customer.auth_backends.EmailBackend',
-    )
-    update(settingsDict, ADDING_AUTHENTICATION_BACKENDS)
+
     #=========================================================================
     if enablePaypal:
         pass
